@@ -23,7 +23,7 @@ def metrics(func, X, y, kind, formatstr="{:,.2f}"):
     return df_to_json_table(table, date_format="iso", date_unit="s", double_precision=2)
 
 
-def largest_errors(func, X, y, n=25):
+def largest_errors(func, X, y, profile_columns, n=25):
     """Return observations with largest errors in predictions"""
     pred = func(X).to_numpy()
 
@@ -42,6 +42,7 @@ def largest_errors(func, X, y, n=25):
     first = ["Predicted Value", "Actual Value", "Delta"]
     last = [x for x in cols if x not in first]
     df = df.reindex(columns=first + last)
+    df = df[profile_columns]
 
     return df_to_json_table(df, date_format="iso", date_unit="s", double_precision=2)
 
